(* ::Package:: *)

(* %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Model file: resonance annihilation scenario

Resonance Fermion Fermion -> Vector -> Fermion Fermion

Model parameters:

    mDM     -   DM mass
    mu      -   m_final/m_DM
    delta   -   quadratic distance from the resonance
    gmma    -   width/resonance mass
    rho     -   normalized combination of couplings: Sqrt[(lambda * g)]

*************** suggested accuracy settings  ***************
plotPoints  =   200;
Np          =   2000;
qN          =   200;
These depend on the parameter choices, where they can be relaxed far away
or above the resonance, while perhaps even pushed to larger values if the
resonance is very narrow and probing the high energy tail of the distribution

Version: 09-12-2020
Contact: Andrzej Hryczuk (NCBJ)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% *)

(*********************** specification of the model ***************************)

Print["-----------------Model: Resonance annihilation scenario (vector mediator) ----------------"];

(* fixed for the model *)
gDM     = 2;  (* internal degrees of freedom *)

cardinfo:={"-------- card: "<>parameters<>"  mDM="<>ToString[N[mDM]]<>
		   "  mu="<>ToString[N[mu],CForm]<>"  delta="<>ToString[N[delta],CForm]<>
		   "  tildegamma="<>ToString[N[tildegamma],CForm]<>"  rho="<>ToString[N[rho],CForm]<>
		   " --------"};

(*************************** annihilation cross section ***********************)

sv[ss_]         :=  -(((1+delta)^2 rho^4 Sqrt[(4 mDM^2-ss) (4 mDM^2 mu^2-ss)] (2 mDM^2+ss)
			(2 mDM^2 mu^2+ss))/(12 \[Pi] (2 mDM^2-ss) Sqrt[ss (-4 mDM^2+ss)]
			(16 (1+tildegamma^2) mDM^4-8 (1+delta) mDM^2 ss+(1+delta)^2 ss^2)));

resonance       :=  If[delta<0,{4mDM^2/(1+delta)},{}]; (* resonance present *)
threshold       :=  {};

(**************************  momentum transfer rate  **************************)

scatttype       =   "M2"; (*gamma(x) is computed from supplied amplitude squared*)

(* t averaged amplitude squared, i.e. <|M|^2>_t *)
M2scatthat[mu_,delta_,gmma_][kt_]:=-((8 rho^4 (-(((1+delta) kt^2 mu^2
										(-8-2 delta-4 Sqrt[1+kt^2] mu-4 delta Sqrt[1+kt^2] mu-3 mu^2-
											4 delta mu^2-delta^2 mu^2-(1+delta)^2 kt^2 mu^2+
											((1+delta)^2 kt^4 mu^4)/(1+2 Sqrt[1+kt^2] mu+mu^2)^2-
											((1+delta) kt^2 mu^2 (4+delta+2 Sqrt[1+kt^2] mu+
											2 delta Sqrt[1+kt^2] mu+(1+delta) mu^2))
											/(1+2 Sqrt[1+kt^2] mu+mu^2)))/(1+2 Sqrt[1+kt^2] mu+mu^2))
											-(8+2 delta+4 Sqrt[1+kt^2] mu+4 delta Sqrt[1+kt^2] mu+
											3 mu^2+4 delta mu^2+delta^2 mu^2+(1+delta)^2 kt^2 mu^2)
											(1+((1+delta) kt^2 mu^2)/(1+2 Sqrt[1+kt^2] mu+mu^2))
											Log[1+((1+delta) kt^2 mu^2)/(1+2 Sqrt[1+kt^2] mu+mu^2)]))
											/((1+delta)^2 kt^4 mu^4 (1+((1+delta) kt^2 mu^2)/(1+2 Sqrt[1+kt^2] mu+mu^2))));
Nscatt          =   2;  (* scattering on both fermions + antifermions *)
(* calculation of the momentum transfer rate *)
dgamma[x_,kt_]  :=  Nscatt (mu^5 x)/(48\[Pi]^3) (mDM/gDM) (kt^5/om[1,kt])/(Exp[om[1,kt]mu x]+1)(1-1/(Exp[om[1,kt]mu x]+1)) M2scatthat[mu,delta,gmma][kt];

gamma[x_]       :=  Quiet[With[{mu=mu},Check[
 NIntegrate[ dgamma[x,kt],{kt, 0, 10/mu},WorkingPrecision->MachinePrecision,
    MinRecursion -> 1,Method -> {"GlobalAdaptive", "SymbolicProcessing" -> 0.1}
    ],minnumber,NIntegrate::slwcon]]];
(* where energy dispersion relation *)
om[m_, k_]      :=  Sqrt[k^2 + m^2];
